# symmathSBML
This package provides sympy symbolic mathematics for SBML models.

## Key Features
* creating sympy Symbols for model species and parameters;
* creating sympy expressions for the equations of the reaction network;
* creating a symbolic Jacobian of the chemical species;
* ability to substitute parameter and species values;
* plot of the sensitivity of the Jacobian to changes in species values.

## Usage Example
Look [here](https://github.com/ModelEngineering/symmathSBML/blob/master/notebooks/Illustrate-SymmathSBML.pdf) for a detailed use case.
